==> tur-request_1.2.1.tar.gz: tur-request/tur-request.tcl <==
##############################################################################
# Tur-Request.tcl 1.3 by Turranius                                           #
# Change triggers below to whatever you want the trigger the script with.    #
# If tur-request.sh is not located in /glftpd/bin/ then change the path      #
# to all 'set binary' below.                                                 #
# o = ops only. - = public.                                                  #
##############################################################################

bind pub o !request pub:turrequests
bind msg o !request msg:turrequests

bind pub - !reqfilled pub:turreqfilled
bind msg - !reqfilled msg:turreqfilled

bind pub - !requests pub:turrequeststatus
bind msg - !requests msg:turrequeststatus

bind pub o !reqdel pub:turrequestdel
bind msg o !reqdel msg:turrequestdel

bind pub o !reqwipe pub:turrequestwipe
bind msg o !reqwipe msg:turrequestwipe



proc pub:turrequests {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary request $who $arg] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turrequests { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary request $who $arg] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}


proc pub:turreqfilled {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqfilled $who $arg] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turreqfilled { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqfilled $who $arg] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}


proc pub:turrequeststatus {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 foreach line [split [exec $binary status] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turrequeststatus { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 foreach line [split [exec $binary status] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}

proc pub:turrequestwipe {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqwipe $who $arg] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turrequestwipe { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqwipe $who $arg] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}

proc pub:turrequestdel {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqfilled $who -hide $arg] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turrequestdel { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqfilled $who -hide $arg] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}

putlog "Tur-Request.tcl 1.3 by Turranius loaded"

==> tur-request_2.0.tar.gz: tur-request/tur-request.tcl <==
##############################################################################
# Tur-Request.tcl 1.4 by Turranius                                           #
# Change triggers below to whatever you want the trigger the script with.    #
# If tur-request.sh is not located in /glftpd/bin/ then change the path      #
# to all 'set binary' below.                                                 #
# o = ops only. - = public.                                                  #
##############################################################################

bind pub o !request pub:turrequests
bind msg o !request msg:turrequests

bind pub - !reqfilled pub:turreqfilled
bind msg - !reqfilled msg:turreqfilled

bind pub - !requests pub:turrequeststatus
bind msg - !requests msg:turrequeststatus

bind pub o !reqdel pub:turrequestdel
bind msg o !reqdel msg:turrequestdel

bind pub o !reqwipe pub:turrequestwipe
bind msg o !reqwipe msg:turrequestwipe



proc pub:turrequests {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary request $who $arg] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turrequests { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary request $who $arg] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}


proc pub:turreqfilled {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqfilled $who $arg] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turreqfilled { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqfilled $who $arg] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}


proc pub:turrequeststatus {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 foreach line [split [exec $binary status] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turrequeststatus { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 foreach line [split [exec $binary status] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}

proc pub:turrequestwipe {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqwipe $who $arg] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turrequestwipe { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqwipe $who $arg] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}

proc pub:turrequestdel {nick uhost handle chan arg} {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqdel $who $arg] "\n"] {
      putquick "PRIVMSG $chan :$line"
 }
}

proc msg:turrequestdel { nick host hand arg } {
 set binary {/glftpd/bin/tur-request.sh}
 set who $nick
 foreach line [split [exec $binary reqdel $who $arg] "\n"] {
      putquick "PRIVMSG $nick :$line"
 }
}

putlog "Tur-Request.tcl 1.4 by Turranius loaded"
